@@ -1,30 +1,15 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2016-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
-# Copyright 2015 Daniel Schadt
+# SPDX-FileCopyrightText: Daniel Schadt
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """pdf.js integration for qutebrowser."""
 
 import os
 
-from PyQt5.QtCore import QUrl, QUrlQuery
+from qutebrowser.qt.core import QUrl, QUrlQuery
 
-from qutebrowser.utils import resources, javascript, jinja, standarddir, log
+from qutebrowser.utils import resources, javascript, jinja, standarddir, log, urlutils
 from qutebrowser.config import config
 
 
@@ -76,14 +61,18 @@ def generate_pdfjs_page(filename, url):
     html = html.replace('</body>',
                         '</body><script>{}</script>'.format(script))
     # WORKAROUND for the fact that PDF.js tries to use the Fetch API even with
-    # qute:// URLs.
-    pdfjs_script = '<script src="../build/pdf.js"></script>'
-    html = html.replace(pdfjs_script,
-                        '<script>window.Response = undefined;</script>\n' +
-                        pdfjs_script)
+    # qute:// URLs, this is probably no longer needed in PDFjs 4+. See #4235
+    html = html.replace(
+        '<head>',
+        '<head>\n<script>window.Response = undefined;</script>\n'
+    )
     return html
 
 
+def _get_polyfills() -> str:
+    return resources.read_file("javascript/pdfjs_polyfills.js")
+
+
 def _generate_pdfjs_script(filename):
     """Generate the script that shows the pdf with pdf.js.
 
@@ -95,24 +84,33 @@ def _generate_pdfjs_script(filename):
     url_query.addQueryItem('filename', filename)
     url.setQuery(url_query)
 
-    js_url = javascript.to_js(
-        url.toString(QUrl.FullyEncoded))  # type: ignore[arg-type]
+    js_url = javascript.to_js(url.toString(urlutils.FormatOption.ENCODED))
 
     return jinja.js_environment.from_string("""
-        document.addEventListener("DOMContentLoaded", function() {
-          if (typeof window.PDFJS !== 'undefined') {
-              // v1.x
-              window.PDFJS.verbosity = window.PDFJS.VERBOSITY_LEVELS.info;
-          } else {
-              // v2.x
-              const options = window.PDFViewerApplicationOptions;
-              options.set('verbosity', pdfjsLib.VerbosityLevel.INFOS);
-          }
+        {{ polyfills }}
 
-          const viewer = window.PDFView || window.PDFViewerApplication;
-          viewer.open({{ url }});
+        document.addEventListener("DOMContentLoaded", function() {
+            if (typeof window.PDFJS !== 'undefined') {
+                // v1.x
+                window.PDFJS.verbosity = window.PDFJS.VERBOSITY_LEVELS.info;
+            } else {
+                // v2.x+
+                const options = window.PDFViewerApplicationOptions;
+                options.set('verbosity', pdfjsLib.VerbosityLevel.INFOS);
+            }
+
+            if (typeof window.PDFView !== 'undefined') {
+                // < v1.6
+                window.PDFView.open({{ url }});
+            } else {
+                // v1.6+
+                window.PDFViewerApplication.open({
+                    url: {{ url }},
+                    originalUrl: {{ url }}
+                });
+            }
         });
-    """).render(url=js_url)
+    """).render(url=js_url, polyfills=_get_polyfills())
 
 
 def get_pdfjs_res_and_path(path):
@@ -156,6 +154,14 @@ def get_pdfjs_res_and_path(path):
             log.misc.warning("OSError while reading PDF.js file: {}".format(e))
             raise PDFJSNotFound(path) from None
 
+    if path == "build/pdf.worker.mjs":
+        content = b"\n".join(
+            [
+                _get_polyfills().encode("ascii"),
+                content,
+            ]
+        )
+
     return content, file_path
 
 
@@ -210,10 +216,24 @@ def _read_from_system(system_path, names):
     return (None, None)
 
 
+def get_pdfjs_js_path():
+    """Checks for pdf.js main module availability and returns the path if available."""
+    paths = ['build/pdf.js', 'build/pdf.mjs']
+    for path in paths:
+        try:
+            get_pdfjs_res(path)
+        except PDFJSNotFound:
+            pass
+        else:
+            return path
+
+    raise PDFJSNotFound(" or ".join(paths))
+
+
 def is_available():
-    """Return true if a pdfjs installation is available."""
+    """Return true if certain parts of a pdfjs installation are available."""
     try:
-        get_pdfjs_res('build/pdf.js')
+        get_pdfjs_js_path()
         get_pdfjs_res('web/viewer.html')
     except PDFJSNotFound:
         return False
@@ -237,7 +257,7 @@ def get_main_url(filename: str, original_url: QUrl) -> QUrl:
     query = QUrlQuery()
     query.addQueryItem('filename', filename)  # read from our JS
     query.addQueryItem('file', '')  # to avoid pdfjs opening the default PDF
-    urlstr = original_url.toString(QUrl.FullyEncoded)  # type: ignore[arg-type]
+    urlstr = original_url.toString(urlutils.FormatOption.ENCODED)
     query.addQueryItem('source', urlstr)
     url.setQuery(query)
     return url
