@@ -1,26 +1,11 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2014-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """QtWebKit specific qute://* handlers and glue code."""
 
-from PyQt5.QtCore import QUrl
-from PyQt5.QtNetwork import QNetworkReply, QNetworkAccessManager
+from qutebrowser.qt.core import QUrl
+from qutebrowser.qt.network import QNetworkReply, QNetworkAccessManager
 
 from qutebrowser.browser import qutescheme
 from qutebrowser.browser.webkit.network import networkreply
@@ -38,10 +23,10 @@ def handler(request, operation, current_url):
     Return:
         A QNetworkReply.
     """
-    if operation != QNetworkAccessManager.GetOperation:
+    if operation != QNetworkAccessManager.Operation.GetOperation:
         return networkreply.ErrorNetworkReply(
             request, "Unsupported request type",
-            QNetworkReply.ContentOperationNotPermittedError)
+            QNetworkReply.NetworkError.ContentOperationNotPermittedError)
 
     url = request.url()
 
@@ -53,22 +38,22 @@ def handler(request, operation, current_url):
                                         url.toDisplayString()))
             return networkreply.ErrorNetworkReply(
                 request, "Invalid qute://settings request",
-                QNetworkReply.ContentAccessDenied)
+                QNetworkReply.NetworkError.ContentAccessDenied)
 
     try:
         mimetype, data = qutescheme.data_for_url(url)
     except qutescheme.Error as e:
         errors = {
             qutescheme.NotFoundError:
-                QNetworkReply.ContentNotFoundError,
+                QNetworkReply.NetworkError.ContentNotFoundError,
             qutescheme.UrlInvalidError:
-                QNetworkReply.ContentOperationNotPermittedError,
+                QNetworkReply.NetworkError.ContentOperationNotPermittedError,
             qutescheme.RequestDeniedError:
-                QNetworkReply.ContentAccessDenied,
+                QNetworkReply.NetworkError.ContentAccessDenied,
             qutescheme.SchemeOSError:
-                QNetworkReply.ContentNotFoundError,
+                QNetworkReply.NetworkError.ContentNotFoundError,
             qutescheme.Error:
-                QNetworkReply.InternalServerError,
+                QNetworkReply.NetworkError.InternalServerError,
         }
         exctype = type(e)
         log.misc.error("{} while handling qute://* URL".format(
