@@ -1,30 +1,24 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2017-2021 Ryan Roden-Corrent (rcorre) <ryan@rcorre.net>
+# SPDX-FileCopyrightText: Ryan Roden-Corrent (rcorre) <ryan@rcorre.net>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """A model that proxies access to one or more completion categories."""
 
-from typing import MutableSequence
+from typing import overload, Optional, Any, cast
+from collections.abc import MutableSequence
 
-from PyQt5.QtCore import Qt, QModelIndex, QAbstractItemModel
+from qutebrowser.qt import machinery
+from qutebrowser.qt.core import Qt, QModelIndex, QAbstractItemModel, QObject
 
 from qutebrowser.utils import log, qtutils, utils
 from qutebrowser.api import cmdutils
+from qutebrowser.completion.models import BaseCategory
+
+
+if machinery.IS_QT5:
+    _FlagType = Qt.ItemFlags
+else:
+    _FlagType = Qt.ItemFlag
 
 
 class CompletionModel(QAbstractItemModel):
@@ -43,9 +37,9 @@ class CompletionModel(QAbstractItemModel):
     def __init__(self, *, column_widths=(30, 70, 0), parent=None):
         super().__init__(parent)
         self.column_widths = column_widths
-        self._categories: MutableSequence[QAbstractItemModel] = []
+        self._categories: MutableSequence[BaseCategory] = []
 
-    def _cat_from_idx(self, index):
+    def _cat_from_idx(self, index: QModelIndex) -> Optional[BaseCategory]:
         """Return the category pointed to by the given index.
 
         Args:
@@ -59,11 +53,11 @@ class CompletionModel(QAbstractItemModel):
             return self._categories[index.row()]
         return None
 
-    def add_category(self, cat):
+    def add_category(self, cat: BaseCategory) -> None:
         """Add a completion category to the model."""
         self._categories.append(cat)
 
-    def data(self, index, role=Qt.DisplayRole):
+    def data(self, index: QModelIndex, role: int = Qt.ItemDataRole.DisplayRole) -> Any:
         """Return the item data for index.
 
         Override QAbstractItemModel::data.
@@ -74,7 +68,7 @@ class CompletionModel(QAbstractItemModel):
 
         Return: The item data, or None on an invalid index.
         """
-        if role != Qt.DisplayRole:
+        if role != Qt.ItemDataRole.DisplayRole:
             return None
         cat = self._cat_from_idx(index)
         if cat:
@@ -89,24 +83,24 @@ class CompletionModel(QAbstractItemModel):
         idx = cat.index(index.row(), index.column())
         return cat.data(idx)
 
-    def flags(self, index):
+    def flags(self, index: QModelIndex) -> _FlagType:
         """Return the item flags for index.
 
         Override QAbstractItemModel::flags.
 
-        Return: The item flags, or Qt.NoItemFlags on error.
+        Return: The item flags, or Qt.ItemFlag.NoItemFlags on error.
         """
         if not index.isValid():
-            return Qt.NoItemFlags
+            return cast(_FlagType, Qt.ItemFlag.NoItemFlags)
         if index.parent().isValid():
             # item
-            return (Qt.ItemIsEnabled | Qt.ItemIsSelectable |
-                    Qt.ItemNeverHasChildren)
+            return (Qt.ItemFlag.ItemIsEnabled | Qt.ItemFlag.ItemIsSelectable |
+                    Qt.ItemFlag.ItemNeverHasChildren)
         else:
             # category
-            return Qt.NoItemFlags
+            return cast(_FlagType, Qt.ItemFlag.NoItemFlags)
 
-    def index(self, row, col, parent=QModelIndex()):
+    def index(self, row: int, col: int, parent: QModelIndex = QModelIndex()) -> QModelIndex:
         """Get an index into the model.
 
         Override QAbstractItemModel::index.
@@ -123,7 +117,21 @@ class CompletionModel(QAbstractItemModel):
             return self.createIndex(row, col, self._categories[parent.row()])
         return self.createIndex(row, col, None)
 
-    def parent(self, index):
+    @overload
+    def parent(self, index: QModelIndex) -> QModelIndex:
+        ...
+
+    if machinery.IS_QT5:
+        @overload
+        def parent(self) -> QObject:
+            ...
+
+    else:
+        @overload
+        def parent(self) -> Optional[QObject]:
+            ...
+
+    def parent(self, index=None):
         """Get an index to the parent of the given index.
 
         Override QAbstractItemModel::parent.
@@ -131,6 +139,9 @@ class CompletionModel(QAbstractItemModel):
         Args:
             index: The QModelIndex to get the parent index for.
         """
+        if not index:
+            return QObject.parent(self)
+
         parent_cat = index.internalPointer()
         if not parent_cat:
             # categories have no parent
@@ -180,10 +191,11 @@ class CompletionModel(QAbstractItemModel):
             pattern: The filter pattern to set.
         """
         log.completion.debug("Setting completion pattern '{}'".format(pattern))
-        self.layoutAboutToBeChanged.emit()  # type: ignore[attr-defined]
+        self.layoutAboutToBeChanged.emit()
         for cat in self._categories:
-            cat.set_pattern(pattern)
-        self.layoutChanged.emit()  # type: ignore[attr-defined]
+            # FIXME:mypy define a Protocol for set_pattern?
+            cat.set_pattern(pattern)  # type: ignore[attr-defined]
+        self.layoutChanged.emit()
 
     def first_item(self):
         """Return the index of the first child (non-category) in the model."""
