@@ -1,37 +1,30 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2017-2019 Ryan Roden-Corrent (rcorre) <ryan@rcorre.net>
+# SPDX-FileCopyrightText: Ryan Roden-Corrent (rcorre) <ryan@rcorre.net>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """Completion category that uses a list of tuples as a data source."""
 
 import re
+from collections.abc import Iterable
 
-from PyQt5.QtCore import Qt, QSortFilterProxyModel, QRegExp
-from PyQt5.QtGui import QStandardItem, QStandardItemModel
+from qutebrowser.qt.core import QSortFilterProxyModel, QRegularExpression
+from qutebrowser.qt.gui import QStandardItem, QStandardItemModel
+from qutebrowser.qt.widgets import QWidget
 
+from qutebrowser.completion.models import util, BaseCategory
 from qutebrowser.utils import qtutils, log
 
 
-class ListCategory(QSortFilterProxyModel):
+class ListCategory(QSortFilterProxyModel, BaseCategory):
 
     """Expose a list of items as a category for the CompletionModel."""
 
-    def __init__(self, name, items, sort=True, delete_func=None, parent=None):
+    def __init__(self,
+                 name: str,
+                 items: Iterable[tuple[str, ...]],
+                 sort: bool = True,
+                 delete_func: util.DeleteFuncType = None,
+                 parent: QWidget = None):
         super().__init__(parent)
         self.name = name
         self.srcmodel = QStandardItemModel(parent=self)
@@ -51,12 +44,19 @@ class ListCategory(QSortFilterProxyModel):
         Args:
             val: The value to set.
         """
+        if len(val) > 5000:  # avoid crash on huge search terms (#5973)
+            log.completion.warning(f"Trimming {len(val)}-char pattern to 5000")
+            val = val[:5000]
         self._pattern = val
-        val = re.sub(r' +', r' ', val)  # See #1919
-        val = re.escape(val)
-        val = val.replace(r'\ ', '.*')
-        rx = QRegExp(val, Qt.CaseInsensitive)
-        self.setFilterRegExp(rx)
+
+        # Positive lookahead per search term. This means that all search terms must
+        # be matched but they can be matched anywhere in the string, so they can be
+        # in any order. For example "foo bar" -> "(?=.*foo)(?=.*bar)"
+        re_pattern = "^" + "".join(f"(?=.*{re.escape(term)})" for term in val.split())
+
+        rx = QRegularExpression(re_pattern, QRegularExpression.PatternOption.CaseInsensitiveOption)
+        qtutils.ensure_valid(rx)
+        self.setFilterRegularExpression(rx)
         self.invalidate()
         sortcol = 0
         self.sort(sortcol)
