@@ -1,21 +1,6 @@
-/**
- * Copyright 2016-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
- *
- * This file is part of qutebrowser.
- *
- * qutebrowser is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * qutebrowser is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 /**
  * The connection for web elements between Python and Javascript works like
@@ -197,8 +182,12 @@ window._qutebrowser.webelem = (function() {
         try {
             frame.document; // eslint-disable-line no-unused-expressions
             return true;
-        } catch (err) {
-            return false;
+        } catch (exc) {
+            if (exc instanceof DOMException && exc.name === "SecurityError") {
+                // FIXME:qtwebengine This does not work for cross-origin frames.
+                return false;
+            }
+            throw exc;
         }
     }
 
