@@ -1,21 +1,6 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2014-2020 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """Utils regarding URL handling."""
 
@@ -25,10 +10,19 @@ import os.path
 import ipaddress
 import posixpath
 import urllib.parse
-import typing
+import mimetypes
+from typing import Optional, Union, cast, TYPE_CHECKING
+from collections.abc import Iterable
 
-from PyQt5.QtCore import QUrl, QUrlQuery
-from PyQt5.QtNetwork import QHostInfo, QHostAddress, QNetworkProxy
+from qutebrowser.qt import machinery
+from qutebrowser.qt.core import QUrl, QUrlQuery
+from qutebrowser.qt.network import QHostInfo, QHostAddress, QNetworkProxy
+# WORKAROUND for
+# https://www.riverbankcomputing.com/pipermail/pyqt/2024-December/046096.html
+if TYPE_CHECKING and machinery.IS_QT6:
+    from qutebrowser.qt.core import QChar
+else:
+    QChar = str
 
 from qutebrowser.api import cmdutils
 from qutebrowser.config import config
@@ -40,6 +34,58 @@ from qutebrowser.browser.network import pac
 # https://github.com/qutebrowser/qutebrowser/issues/108
 
 
+if machinery.IS_QT6:
+    UrlFlagsType = Union[QUrl.UrlFormattingOption, QUrl.ComponentFormattingOption]
+
+    class FormatOption:
+        """Simple wrapper around Qt enums to fix typing problems on Qt 5."""
+
+        ENCODED = QUrl.ComponentFormattingOption.FullyEncoded
+        ENCODE_UNICODE = QUrl.ComponentFormattingOption.EncodeUnicode
+        DECODE_RESERVED = QUrl.ComponentFormattingOption.DecodeReserved
+
+        REMOVE_SCHEME = QUrl.UrlFormattingOption.RemoveScheme
+        REMOVE_PASSWORD = QUrl.UrlFormattingOption.RemovePassword
+        REMOVE_QUERY = QUrl.UrlFormattingOption.RemoveQuery
+else:
+    UrlFlagsType = Union[
+        QUrl.FormattingOptions,
+        QUrl.UrlFormattingOption,
+        QUrl.ComponentFormattingOption,
+        QUrl.ComponentFormattingOptions,
+    ]
+
+    class _QtFormattingOptions(QUrl.FormattingOptions):
+        """WORKAROUND for invalid stubs.
+
+        Teach mypy that | works for QUrl.FormattingOptions.
+        """
+
+        def __or__(self, f: UrlFlagsType) -> '_QtFormattingOptions':
+            return super() | f  # type: ignore[operator,return-value]
+
+    class FormatOption:
+        """WORKAROUND for invalid stubs.
+
+        Pretend that all ComponentFormattingOption values are also valid
+        QUrl.FormattingOptions values, i.e. can be passed to QUrl.toString().
+        """
+
+        ENCODED = cast(
+            _QtFormattingOptions, QUrl.ComponentFormattingOption.FullyEncoded)
+        ENCODE_UNICODE = cast(
+            _QtFormattingOptions, QUrl.ComponentFormattingOption.EncodeUnicode)
+        DECODE_RESERVED = cast(
+            _QtFormattingOptions, QUrl.ComponentFormattingOption.DecodeReserved)
+
+        REMOVE_SCHEME = cast(
+            _QtFormattingOptions, QUrl.UrlFormattingOption.RemoveScheme)
+        REMOVE_PASSWORD = cast(
+            _QtFormattingOptions, QUrl.UrlFormattingOption.RemovePassword)
+        REMOVE_QUERY = cast(
+            _QtFormattingOptions, QUrl.UrlFormattingOption.RemoveQuery)
+
+
 # URL schemes supported by QtWebEngine
 WEBENGINE_SCHEMES = [
     'about',
@@ -55,7 +101,12 @@ WEBENGINE_SCHEMES = [
 ]
 
 
-class InvalidUrlError(Exception):
+class Error(Exception):
+
+    """Base class for errors in this module."""
+
+
+class InvalidUrlError(Error):
 
     """Error raised if a function got an invalid URL."""
 
@@ -67,8 +118,7 @@ class InvalidUrlError(Exception):
         super().__init__(self.msg)
 
 
-def _parse_search_term(s: str) -> typing.Tuple[typing.Optional[str],
-                                               typing.Optional[str]]:
+def _parse_search_term(s: str) -> tuple[Optional[str], Optional[str]]:
     """Get a search engine name and search term from a string.
 
     Args:
@@ -84,12 +134,13 @@ def _parse_search_term(s: str) -> typing.Tuple[typing.Optional[str],
 
     if len(split) == 2:
         if split[0] in config.val.url.searchengines:
-            engine = split[0]  # type: typing.Optional[str]
-            term = split[1]  # type: typing.Optional[str]
+            engine: Optional[str] = split[0]
+            term: Optional[str] = split[1]
         else:
             engine = None
             term = s
     else:
+        # pylint: disable=else-if-used
         if config.val.url.open_base_url and s in config.val.url.searchengines:
             engine = s
             term = None
@@ -122,12 +173,12 @@ def _get_search_url(txt: str) -> QUrl:
                                     unquoted=term,
                                     quoted=quoted_term,
                                     semiquoted=semiquoted_term)
-        url = qurl_from_user_input(evaluated)
+        url = QUrl.fromUserInput(evaluated)
     else:
-        url = qurl_from_user_input(config.val.url.searchengines[engine])
-        url.setPath(None)  # type: ignore[arg-type]
-        url.setFragment(None)  # type: ignore[arg-type]
-        url.setQuery(None)  # type: ignore[call-overload]
+        url = QUrl.fromUserInput(config.val.url.searchengines[engine])
+        url.setPath(qtutils.QT_NONE)
+        url.setFragment(qtutils.QT_NONE)
+        url.setQuery(qtutils.QT_NONE)
     qtutils.ensure_valid(url)
     return url
 
@@ -141,7 +192,7 @@ def _is_url_naive(urlstr: str) -> bool:
     Return:
         True if the URL really is a URL, False otherwise.
     """
-    url = qurl_from_user_input(urlstr)
+    url = QUrl.fromUserInput(urlstr)
     assert url.isValid()
     host = url.host()
 
@@ -166,7 +217,7 @@ def _is_url_dns(urlstr: str) -> bool:
     Return:
         True if the URL really is a URL, False otherwise.
     """
-    url = qurl_from_user_input(urlstr)
+    url = QUrl.fromUserInput(urlstr)
     assert url.isValid()
 
     if (utils.raises(ValueError, ipaddress.ip_address, urlstr) and
@@ -182,7 +233,7 @@ def _is_url_dns(urlstr: str) -> bool:
         return False
     log.url.debug("Doing DNS request for {}".format(host))
     info = QHostInfo.fromName(host)
-    return not info.error()
+    return info.error() == QHostInfo.HostInfoError.NoError
 
 
 def fuzzy_url(urlstr: str,
@@ -215,10 +266,10 @@ def fuzzy_url(urlstr: str,
         try:
             url = _get_search_url(urlstr)
         except ValueError:  # invalid search engine
-            url = qurl_from_user_input(urlstr)
+            url = QUrl.fromUserInput(urlstr)
     else:  # probably an address
         log.url.debug("URL is a fuzzy address")
-        url = qurl_from_user_input(urlstr)
+        url = QUrl.fromUserInput(urlstr)
     log.url.debug("Converting fuzzy term {!r} to URL -> {}".format(
         urlstr, url.toDisplayString()))
     ensure_valid(url)
@@ -268,7 +319,7 @@ def is_url(urlstr: str) -> bool:
 
     urlstr = urlstr.strip()
     qurl = QUrl(urlstr)
-    qurl_userinput = qurl_from_user_input(urlstr)
+    qurl_userinput = QUrl.fromUserInput(urlstr)
 
     if autosearch == 'never':
         # no autosearch, so everything is a URL unless it has an explicit
@@ -302,7 +353,7 @@ def is_url(urlstr: str) -> bool:
         url = True
     elif autosearch == 'dns':
         log.url.debug("Checking via DNS check")
-        # We want to use qurl_from_user_input here, as the user might enter
+        # We want to use QUrl.fromUserInput here, as the user might enter
         # "foo.de" and that should be treated as URL here.
         url = ' ' not in qurl_userinput.userName() and _is_url_dns(urlstr)
     elif autosearch == 'naive':
@@ -314,42 +365,6 @@ def is_url(urlstr: str) -> bool:
     return url
 
 
-def qurl_from_user_input(urlstr: str) -> QUrl:
-    """Get a QUrl based on a user input. Additionally handles IPv6 addresses.
-
-    QUrl.fromUserInput handles something like '::1' as a file URL instead of an
-    IPv6, so we first try to handle it as a valid IPv6, and if that fails we
-    use QUrl.fromUserInput.
-
-    WORKAROUND - https://bugreports.qt.io/browse/QTBUG-41089
-    FIXME - Maybe https://codereview.qt-project.org/#/c/93851/ has a better way
-            to solve this?
-    https://github.com/qutebrowser/qutebrowser/issues/109
-
-    Args:
-        urlstr: The URL as string.
-
-    Return:
-        The converted QUrl.
-    """
-    # First we try very liberally to separate something like an IPv6 from the
-    # rest (e.g. path info or parameters)
-    match = re.fullmatch(r'\[?([0-9a-fA-F:.]+)\]?(.*)', urlstr.strip())
-    if match:
-        ipstr, rest = match.groups()
-    else:
-        ipstr = urlstr.strip()
-        rest = ''
-    # Then we try to parse it as an IPv6, and if we fail use
-    # QUrl.fromUserInput.
-    try:
-        ipaddress.IPv6Address(ipstr)
-    except ipaddress.AddressValueError:
-        return QUrl.fromUserInput(urlstr)
-    else:
-        return QUrl('http://[{}]{}'.format(ipstr, rest))
-
-
 def ensure_valid(url: QUrl) -> None:
     if not url.isValid():
         raise InvalidUrlError(url)
@@ -359,6 +374,7 @@ def invalid_url_error(url: QUrl, action: str) -> None:
     """Display an error message for a URL.
 
     Args:
+        url: The URL to display a message for.
         action: The action which was interrupted by the error.
     """
     if url.isValid():
@@ -380,7 +396,7 @@ def raise_cmdexc_if_invalid(url: QUrl) -> None:
 def get_path_if_valid(pathstr: str,
                       cwd: str = None,
                       relative: bool = False,
-                      check_exists: bool = False) -> typing.Optional[str]:
+                      check_exists: bool = False) -> Optional[str]:
     """Check if path is a valid path.
 
     Args:
@@ -398,7 +414,7 @@ def get_path_if_valid(pathstr: str,
     expanded = os.path.expanduser(pathstr)
 
     if os.path.isabs(expanded):
-        path = expanded  # type: typing.Optional[str]
+        path: Optional[str] = expanded
     elif relative and cwd:
         path = os.path.join(cwd, expanded)
     elif relative:
@@ -425,27 +441,37 @@ def get_path_if_valid(pathstr: str,
     return path
 
 
-def filename_from_url(url: QUrl) -> typing.Optional[str]:
+def filename_from_url(url: QUrl, fallback: str = None) -> Optional[str]:
     """Get a suitable filename from a URL.
 
     Args:
         url: The URL to parse, as a QUrl.
+        fallback: Value to use if no name can be determined.
 
     Return:
         The suggested filename as a string, or None.
     """
     if not url.isValid():
-        return None
+        return fallback
+
+    if url.scheme().lower() == 'data':
+        mimetype, _encoding = mimetypes.guess_type(url.toString())
+        if not mimetype:
+            return fallback
+
+        ext = utils.mimetype_extension(mimetype) or ''
+        return 'download' + ext
+
     pathname = posixpath.basename(url.path())
     if pathname:
         return pathname
     elif url.host():
         return url.host() + '.html'
     else:
-        return None
+        return fallback
 
 
-HostTupleType = typing.Tuple[str, str, int]
+HostTupleType = tuple[str, str, int]
 
 
 def host_tuple(url: QUrl) -> HostTupleType:
@@ -499,22 +525,43 @@ def same_domain(url1: QUrl, url2: QUrl) -> bool:
     For example example.com and www.example.com are considered the same. but
     example.co.uk and test.co.uk are not.
 
+    If the URL's schemes or ports are different, they are always treated as not equal.
+
     Return:
         True if the domains are the same, False otherwise.
     """
     ensure_valid(url1)
     ensure_valid(url2)
 
-    suffix1 = url1.topLevelDomain()
-    suffix2 = url2.topLevelDomain()
+    if url1.scheme() != url2.scheme():
+        return False
+    if url1.port() != url2.port():
+        return False
+
+    # QUrl.topLevelDomain() got removed in Qt 6:
+    # https://bugreports.qt.io/browse/QTBUG-80308
+    #
+    # However, we should never land here if we are on Qt 6:
+    #
+    # On QtWebEngine, we don't have a QNetworkAccessManager attached to a tab
+    # (all tab-specific downloads happen via the QtWebEngine network stack).
+    # Thus, ensure_valid(url2) above will raise InvalidUrlError, which is
+    # handled in NetworkManager.
+    #
+    # There are no other callers of same_domain, and url2 will only be ever valid when
+    # we use a NetworkManager from QtWebKit. However, QtWebKit is Qt 5 only.
+    assert machinery.IS_QT5, machinery.INFO
+
+    suffix1 = url1.topLevelDomain()  # type: ignore[attr-defined,unused-ignore]
+    suffix2 = url2.topLevelDomain()  # type: ignore[attr-defined,unused-ignore]
     if not suffix1:
         return url1.host() == url2.host()
 
     if suffix1 != suffix2:
         return False
 
-    domain1 = url1.host()[:-len(suffix1)].split('.')[-1]
-    domain2 = url2.host()[:-len(suffix2)].split('.')[-1]
+    domain1 = url1.host().removesuffix(suffix1).split('.')[-1]
+    domain2 = url2.host().removesuffix(suffix2).split('.')[-1]
     return domain1 == domain2
 
 
@@ -534,7 +581,7 @@ def file_url(path: str) -> str:
         path: The absolute path to the local file
     """
     url = QUrl.fromLocalFile(path)
-    return url.toString(QUrl.FullyEncoded)  # type: ignore[arg-type]
+    return url.toString(FormatOption.ENCODED)
 
 
 def data_url(mimetype: str, data: bytes) -> QUrl:
@@ -556,31 +603,17 @@ def safe_display_string(qurl: QUrl) -> str:
     """
     ensure_valid(qurl)
 
-    host = qurl.host(QUrl.FullyEncoded)
-    if '..' in host:  # pragma: no cover
-        # WORKAROUND for https://bugreports.qt.io/browse/QTBUG-60364
-        return '(unparseable URL!) {}'.format(qurl.toDisplayString())
+    host = qurl.host(QUrl.ComponentFormattingOption.FullyEncoded)
+    assert '..' not in host, qurl  # https://bugreports.qt.io/browse/QTBUG-60364
 
     for part in host.split('.'):
-        url_host = qurl.host(QUrl.FullyDecoded)
+        url_host = qurl.host(QUrl.ComponentFormattingOption.FullyDecoded)
         if part.startswith('xn--') and host != url_host:
             return '({}) {}'.format(host, qurl.toDisplayString())
 
     return qurl.toDisplayString()
 
 
-def query_string(qurl: QUrl) -> str:
-    """Get a query string for the given URL.
-
-    This is a WORKAROUND for:
-    https://www.riverbankcomputing.com/pipermail/pyqt/2017-November/039702.html
-    """
-    try:
-        return qurl.query()
-    except AttributeError:  # pragma: no cover
-        return QUrlQuery(qurl).query()
-
-
 class InvalidProxyTypeError(Exception):
 
     """Error raised when proxy_from_url gets an unknown proxy type."""
@@ -589,7 +622,7 @@ class InvalidProxyTypeError(Exception):
         super().__init__("Invalid proxy type {}!".format(typ))
 
 
-def proxy_from_url(url: QUrl) -> typing.Union[QNetworkProxy, pac.PACFetcher]:
+def proxy_from_url(url: QUrl) -> Union[QNetworkProxy, pac.PACFetcher]:
     """Create a QNetworkProxy from QUrl and a proxy type.
 
     Args:
@@ -607,10 +640,10 @@ def proxy_from_url(url: QUrl) -> typing.Union[QNetworkProxy, pac.PACFetcher]:
         return fetcher
 
     types = {
-        'http': QNetworkProxy.HttpProxy,
-        'socks': QNetworkProxy.Socks5Proxy,
-        'socks5': QNetworkProxy.Socks5Proxy,
-        'direct': QNetworkProxy.NoProxy,
+        'http': QNetworkProxy.ProxyType.HttpProxy,
+        'socks': QNetworkProxy.ProxyType.Socks5Proxy,
+        'socks5': QNetworkProxy.ProxyType.Socks5Proxy,
+        'direct': QNetworkProxy.ProxyType.NoProxy,
     }
     if scheme not in types:
         raise InvalidProxyTypeError(scheme)
@@ -624,3 +657,57 @@ def proxy_from_url(url: QUrl) -> typing.Union[QNetworkProxy, pac.PACFetcher]:
     if url.password():
         proxy.setPassword(url.password())
     return proxy
+
+
+def parse_javascript_url(url: QUrl) -> str:
+    """Get JavaScript source from the given URL.
+
+    See https://wiki.whatwg.org/wiki/URL_schemes#javascript:_URLs
+    and https://github.com/whatwg/url/issues/385
+    """
+    ensure_valid(url)
+    if url.scheme() != 'javascript':
+        raise Error("Expected a javascript:... URL")
+    if url.authority():
+        raise Error("URL contains unexpected components: {}"
+                    .format(url.authority()))
+
+    urlstr = url.toString(FormatOption.ENCODED)
+    urlstr = urllib.parse.unquote(urlstr)
+
+    code = urlstr.removeprefix('javascript:')
+    if not code:
+        raise Error("Resulted in empty JavaScript code")
+
+    return code
+
+
+def widened_hostnames(hostname: str) -> Iterable[str]:
+    """A generator for widening string hostnames.
+
+    Ex: a.c.foo -> [a.c.foo, c.foo, foo]"""
+    while hostname:
+        yield hostname
+        hostname = hostname.partition(".")[-1]
+
+
+def get_url_yank_text(url: QUrl, *, pretty: bool) -> str:
+    """Get the text that should be yanked for the given URL."""
+    flags = FormatOption.REMOVE_PASSWORD
+    if url.scheme() == 'mailto':
+        flags |= FormatOption.REMOVE_SCHEME
+    if pretty:
+        flags |= FormatOption.DECODE_RESERVED
+    else:
+        flags |= FormatOption.ENCODED
+
+    url_query = QUrlQuery()
+    url_query_str = url.query()
+    if '&' not in url_query_str and ';' in url_query_str:
+        url_query.setQueryDelimiters(cast(QChar, '='), cast(QChar, ';'))
+    url_query.setQuery(url_query_str)
+    for key in dict(url_query.queryItems()):
+        if key in config.val.url.yank_ignored_parameters:
+            url_query.removeQueryItem(key)
+    url.setQuery(url_query)
+    return url.toString(flags)
