@@ -1,22 +1,8 @@
 #!/usr/bin/env python3
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """Check by which hostblock list a host was blocked."""
 
@@ -41,8 +27,8 @@ def main():
 
     for url in configdata.DATA['content.blocking.hosts.lists'].default:
         print("checking {}...".format(url))
-        raw_file = urllib.request.urlopen(url)
-        byte_io = io.BytesIO(raw_file.read())
+        with urllib.request.urlopen(url) as raw_file:
+            byte_io = io.BytesIO(raw_file.read())
         f = hostblock.get_fileobj(byte_io)
         for line in f:
             line = line.decode('utf-8')
