@@ -34,9 +34,9 @@ _qute_scheme_handler = None
 
 
 # Set hypothesis settings
-hypotheses_optional_kwargs = {}
+hypothesis_optional_kwargs = {}
 if "HYPOTHESIS_EXAMPLES_DIR" in os.environ:
-    hypotheses_optional_kwargs[
+    hypothesis_optional_kwargs[
         "database"
     ] = hypothesis.database.DirectoryBasedExampleDatabase(
         os.environ["HYPOTHESIS_EXAMPLES_DIR"]
@@ -46,17 +46,16 @@ hypothesis.settings.register_profile(
     'default', hypothesis.settings(
         deadline=600,
         suppress_health_check=[hypothesis.HealthCheck.function_scoped_fixture],
-        **hypotheses_optional_kwargs,
+        **hypothesis_optional_kwargs,
     )
 )
 hypothesis.settings.register_profile(
     'ci', hypothesis.settings(
-        deadline=None,
+        hypothesis.settings.get_profile('ci'),
         suppress_health_check=[
             hypothesis.HealthCheck.function_scoped_fixture,
-            hypothesis.HealthCheck.too_slow
         ],
-        **hypotheses_optional_kwargs,
+        **hypothesis_optional_kwargs,
     )
 )
 hypothesis.settings.load_profile('ci' if testutils.ON_CI else 'default')
@@ -350,15 +349,26 @@ def apply_fake_os(monkeypatch, request):
 
 @pytest.fixture(scope='session', autouse=True)
 def check_yaml_c_exts():
-    """Make sure PyYAML C extensions are available on CI.
-
-    Not available yet with a nightly Python, see:
-    https://github.com/yaml/pyyaml/issues/630
-    """
-    if testutils.ON_CI and sys.version_info[:2] != (3, 11):
+    """Make sure PyYAML C extensions are available on CI."""
+    if testutils.ON_CI:
         from yaml import CLoader  # pylint: disable=unused-import
 
 
+@pytest.fixture(scope="session", autouse=True)
+def init_qtwe_dict_path(
+    tmp_path_factory: pytest.TempPathFactory, request: pytest.FixtureRequest,
+) -> None:
+    """Initialize spell checking dictionaries for QtWebEngine.
+
+    QtWebEngine stores the dictionary path in a static variable, so we can't do
+    this per-test. Hence the session-scope on this fixture.
+    """
+    if request.config.webengine:  # type: ignore[att-defined]
+        # Set an empty directory path, this is enough for QtWebEngine to not complain.
+        dictionary_dir = tmp_path_factory.mktemp("qtwebengine_dictionaries")
+        os.environ["QTWEBENGINE_DICTIONARIES_PATH"] = str(dictionary_dir)
+
+
 @pytest.hookimpl(tryfirst=True, hookwrapper=True)
 def pytest_runtest_makereport(item, call):
     """Make test information available in fixtures.
