@@ -7,6 +7,12 @@ import logging
 import pytest_bdd as bdd
 bdd.scenarios('prompts.feature')
 
+from qutebrowser.utils import qtutils
+try:
+    from qutebrowser.qt.webenginecore import PYQT_WEBENGINE_VERSION
+except ImportError:
+    PYQT_WEBENGINE_VERSION = None
+
 
 @bdd.when("I load an SSL page")
 def load_ssl_page(quteproc, ssl_server):
@@ -37,6 +43,21 @@ def wait_for_prompt(quteproc):
     quteproc.wait_for(message='Asking question *')
 
 
+@bdd.given("I may need a fresh instance")
+def fresh_instance(quteproc):
+    """Restart qutebrowser to bypass webengine's permission persistance."""
+    # Qt6.8 by default will remember feature grants or denies. When we are
+    # on PyQt6.8 we disable that with the new API, otherwise restart the
+    # browser to make it forget previous prompts.
+    if (
+        qtutils.version_check("6.8", compiled=False)
+        and PYQT_WEBENGINE_VERSION
+        and PYQT_WEBENGINE_VERSION < 0x60800
+    ):
+        quteproc.terminate()
+        quteproc.start()
+
+
 @bdd.then("no prompt should be shown")
 def no_prompt_shown(quteproc):
     quteproc.ensure_not_logged(message='Entering mode KeyMode.* (reason: '
