@@ -1,21 +1,6 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2015-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """Base class for a subprocess run for tests."""
 
@@ -26,9 +11,9 @@ import dataclasses
 
 import pytest
 import pytestqt.wait_signal
-from PyQt5.QtCore import (pyqtSlot, pyqtSignal, QProcess, QObject,
+from qutebrowser.qt.core import (pyqtSlot, pyqtSignal, QProcess, QObject,
                           QElapsedTimer, QProcessEnvironment)
-from PyQt5.QtTest import QSignalSpy
+from qutebrowser.qt.test import QSignalSpy
 
 from helpers import testutils
 
@@ -151,7 +136,7 @@ class Process(QObject):
         self._invalid = []
         self._data = []
         self.proc = QProcess()
-        self.proc.setReadChannel(QProcess.StandardError)
+        self.proc.setReadChannel(QProcess.ProcessChannel.StandardError)
         self.exit_expected = None  # Not started at all yet
 
     def _log(self, line):
@@ -325,7 +310,7 @@ class Process(QObject):
 
     def is_running(self):
         """Check if the process is currently running."""
-        return self.proc.state() == QProcess.Running
+        return self.proc.state() == QProcess.ProcessState.Running
 
     def _match_data(self, value, expected):
         """Helper for wait_for to match a given value.
