@@ -1,21 +1,6 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2018-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """Tests for qutebrowser.components.misccommands."""
 
@@ -78,7 +63,7 @@ def test_debug_trace_exception(mocker):
     """Check that exceptions thrown by hunter.trace are handled."""
     def _mock_exception():
         """Side effect for testing debug_trace's reraise."""
-        raise Exception('message')
+        raise Exception('message')  # pylint: disable=broad-exception-raised
 
     hunter_mock = mocker.patch.object(misccommands, 'hunter')
     hunter_mock.trace.side_effect = _mock_exception
