@@ -75,8 +75,10 @@ class TestQtArgs:
         (['--qt-flag', 'foo', '--qt-flag', 'bar'],
          [sys.argv[0], '--foo', '--bar']),
     ])
-    def test_qt_args(self, monkeypatch, config_stub, args, expected, parser):
+    def test_qt_args(self, request, monkeypatch, config_stub, args, expected, parser):
         """Test commandline with no Qt arguments given."""
+        if request.config.webengine:
+            expected.append("--touch-events=disabled")  # passed unconditionally
         parsed = parser.parse_args(args)
         assert qtargs.qt_args(parsed) == expected
 
@@ -156,14 +158,12 @@ class TestWebEngineArgs:
             assert '--enable-in-process-stack-traces' not in args
 
     @pytest.mark.parametrize(
-        'qt_version, qt6, value, has_arg',
+        'qt6, value, has_arg',
         [
-            ('5.15.2', False, 'auto', False),
-            ('6.5.3', True, 'auto', True),
-            ('6.6.0', True, 'auto', False),
-            ('6.5.3', True, 'always', True),
-            ('6.5.3', True, 'never', False),
-            ('6.6.0', True, 'always', True),
+            (False, 'auto', False),
+            (True, 'auto', True),
+            (True, 'always', True),
+            (True, 'never', False),
         ],
     )
     def test_accelerated_2d_canvas(
@@ -172,12 +172,10 @@ class TestWebEngineArgs:
         version_patcher,
         config_stub,
         monkeypatch,
-        qt_version,
         qt6,
         value,
         has_arg,
     ):
-        version_patcher(qt_version)
         config_stub.val.qt.workarounds.disable_accelerated_2d_canvas = value
         monkeypatch.setattr(machinery, 'IS_QT6', qt6)
 
