@@ -1,21 +1,6 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2016-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """Check how Qt behaves when trying to execute JS."""
 
@@ -28,8 +13,8 @@ def test_simple_js_webkit(webview, js_enabled, expected):
     """With QtWebKit, evaluateJavaScript works when JS is on."""
     # If we get there (because of the webview fixture) we can be certain
     # QtWebKit is available
-    from PyQt5.QtWebKit import QWebSettings
-    webview.settings().setAttribute(QWebSettings.JavascriptEnabled, js_enabled)
+    from qutebrowser.qt.webkit import QWebSettings  # pylint: disable=no-name-in-module
+    webview.settings().setAttribute(QWebSettings.WebAttribute.JavascriptEnabled, js_enabled)
     result = webview.page().mainFrame().evaluateJavaScript('1 + 1')
     assert result == expected
 
@@ -39,8 +24,8 @@ def test_element_js_webkit(webview, js_enabled, expected):
     """With QtWebKit, evaluateJavaScript on an element works with JS off."""
     # If we get there (because of the webview fixture) we can be certain
     # QtWebKit is available
-    from PyQt5.QtWebKit import QWebSettings
-    webview.settings().setAttribute(QWebSettings.JavascriptEnabled, js_enabled)
+    from qutebrowser.qt.webkit import QWebSettings  # pylint: disable=no-name-in-module
+    webview.settings().setAttribute(QWebSettings.WebAttribute.JavascriptEnabled, js_enabled)
     elem = webview.page().mainFrame().documentElement()
     result = elem.evaluateJavaScript('1 + 1')
     assert result == expected
@@ -63,14 +48,14 @@ def test_simple_js_webengine(qtbot, webengineview, qapp,
     """With QtWebEngine, runJavaScript works even when JS is off."""
     # If we get there (because of the webengineview fixture) we can be certain
     # QtWebEngine is available
-    from PyQt5.QtWebEngineWidgets import QWebEngineSettings, QWebEngineScript
+    from qutebrowser.qt.webenginecore import QWebEngineSettings, QWebEngineScript
 
-    assert world in [QWebEngineScript.MainWorld,
-                     QWebEngineScript.ApplicationWorld,
-                     QWebEngineScript.UserWorld]
+    assert world in [QWebEngineScript.ScriptWorldId.MainWorld,
+                     QWebEngineScript.ScriptWorldId.ApplicationWorld,
+                     QWebEngineScript.ScriptWorldId.UserWorld]
 
     settings = webengineview.settings()
-    settings.setAttribute(QWebEngineSettings.JavascriptEnabled, js_enabled)
+    settings.setAttribute(QWebEngineSettings.WebAttribute.JavascriptEnabled, js_enabled)
     qapp.processEvents()
 
     page = webengineview.page()
