@@ -1,26 +1,11 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2014-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 import logging
 
-from PyQt5.QtCore import Qt, QSize
-from PyQt5.QtWidgets import QWidget
+from qutebrowser.qt.core import Qt, QSize
+from qutebrowser.qt.widgets import QWidget
 import pytest
 
 from qutebrowser.misc import miscwidgets
@@ -48,9 +33,9 @@ class TestCommandLineEdit:
 
         cmd_edit.home(True)
         assert cmd_edit.cursorPosition() == len(':')
-        qtbot.keyClick(cmd_edit, Qt.Key_Delete)
+        qtbot.keyClick(cmd_edit, Qt.Key.Key_Delete)
         assert cmd_edit.text() == ':'
-        qtbot.keyClick(cmd_edit, Qt.Key_Backspace)
+        qtbot.keyClick(cmd_edit, Qt.Key.Key_Backspace)
         assert cmd_edit.text() == ':'
 
         qtbot.keyClicks(cmd_edit, 'hey again')
@@ -76,7 +61,7 @@ class TestCommandLineEdit:
         assert cmd_edit.text() == ':hello'
         assert cmd_edit.cursorPosition() == len(':hello')
         for _ in ':hello':
-            qtbot.keyClick(cmd_edit, Qt.Key_Left, modifier=Qt.ShiftModifier)
+            qtbot.keyClick(cmd_edit, Qt.Key.Key_Left, modifier=Qt.KeyboardModifier.ShiftModifier)
         assert cmd_edit.cursorPosition() == len(':')
         assert cmd_edit.selectionStart() == len(':')
 
@@ -110,6 +95,21 @@ class TestWrapperLayout:
 
 class TestFullscreenNotification:
 
+    @pytest.fixture
+    def widget_factory(self, qtbot, key_config_stub, blue_widget):
+        # We need to pass a visible parent widget, so that
+        # FullscreenNotification.__init__ can access
+        # self.window().windowHandle() to get the screen.
+        with qtbot.wait_exposed(blue_widget):
+            blue_widget.show()
+
+        def create():
+            w = miscwidgets.FullscreenNotification(blue_widget)
+            qtbot.add_widget(w)
+            return w
+
+        return create
+
     @pytest.mark.parametrize('bindings, text', [
         ({'<escape>': 'fullscreen --leave'},
          "Press <Escape> to exit fullscreen."),
@@ -117,18 +117,16 @@ class TestFullscreenNotification:
         ({'a': 'fullscreen --leave'}, "Press a to exit fullscreen."),
         ({}, "Page is now fullscreen."),
     ])
-    def test_text(self, qtbot, config_stub, key_config_stub, bindings, text):
+    def test_text(self, widget_factory, config_stub, bindings, text):
         config_stub.val.bindings.default = {}
         config_stub.val.bindings.commands = {'normal': bindings}
-        w = miscwidgets.FullscreenNotification()
-        qtbot.add_widget(w)
-        assert w.text() == text
+        widget = widget_factory()
+        assert widget.text() == text
 
-    def test_timeout(self, qtbot, key_config_stub):
-        w = miscwidgets.FullscreenNotification()
-        qtbot.add_widget(w)
-        with qtbot.wait_signal(w.destroyed):
-            w.set_timeout(1)
+    def test_timeout(self, qtbot, widget_factory):
+        widget = widget_factory()
+        with qtbot.wait_signal(widget.destroyed):
+            widget.set_timeout(1)
 
 
 @pytest.mark.usefixtures('state_config')
@@ -165,10 +163,10 @@ class TestInspectorSplitter:
 
     @pytest.mark.parametrize(
         'position, orientation, inspector_idx, webview_idx', [
-            (inspector.Position.left, Qt.Horizontal, 0, 1),
-            (inspector.Position.right, Qt.Horizontal, 1, 0),
-            (inspector.Position.top, Qt.Vertical, 0, 1),
-            (inspector.Position.bottom, Qt.Vertical, 1, 0),
+            (inspector.Position.left, Qt.Orientation.Horizontal, 0, 1),
+            (inspector.Position.right, Qt.Orientation.Horizontal, 1, 0),
+            (inspector.Position.top, Qt.Orientation.Vertical, 0, 1),
+            (inspector.Position.bottom, Qt.Orientation.Vertical, 1, 0),
         ]
     )
     def test_set_inspector(self, position, orientation,
@@ -260,7 +258,7 @@ class TestInspectorSplitter:
                          new_window_size, exp_inspector_size,
                          position, splitter, fake_inspector, qtbot):
         def resize(dim):
-            size = (QSize(dim, 666) if splitter.orientation() == Qt.Horizontal
+            size = (QSize(dim, 666) if splitter.orientation() == Qt.Orientation.Horizontal
                     else QSize(666, dim))
             splitter.resize(size)
             if splitter.size() != size:
